@@ -10,6 +10,7 @@ from .api import (
     OrderClient,
     OrderChangeClient,
     OrderChangeOfferClient,
+    PartialOfferRequestClient,
     PaymentClient,
     PaymentIntentClient,
     SeatMapClient,
@@ -102,6 +103,11 @@ class Duffel:
         """Order Change Requests API - /air/order_change_requests"""
         return OrderChangeRequestClient(**self._kwargs)
 
+    @lazy_property
+    def partial_offer_requests(self):
+        """Partial Offer Requests API - /air/partial_offer_requests"""
+        return PartialOfferRequestClient(**self._kwargs)
+
     @lazy_property
     def payment_intents(self):
         """Payment Intents API - /payments/payment_intents"""
