@@ -3,7 +3,7 @@ from datetime import datetime
 from typing import Optional, Sequence
 
 from duffel_api.models import Aircraft, Airline, Airport, LoyaltyProgrammeAccount, Place
-from duffel_api.utils import get_and_transform
+from duffel_api.utils import get_and_transform, parse_datetime
 
 
 @dataclass
@@ -96,9 +96,7 @@ class PaymentRequirements:
         """Construct a class instance from a JSON response."""
         return cls(
             payment_required_by=get_and_transform(
-                json,
-                "payment_required_by",
-                lambda value: datetime.strptime(value, "%Y-%m-%dT%H:%M:%SZ"),
+                json, "payment_required_by", parse_datetime
             ),
             price_guarantee_expires_at=get_and_transform(
                 json,
@@ -499,12 +497,3 @@ class Offer:
             total_currency=json["total_currency"],
             total_emissions_kg=json["total_emissions_kg"],
         )
-
-
-def parse_datetime(value: str) -> datetime:
-    # There are inconsistent formats used for this field depending on the
-    # endpoint
-    if len(value) == 20:
-        return datetime.strptime(value, "%Y-%m-%dT%H:%M:%SZ")
-    else:
-        return datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ")
