@@ -495,10 +495,12 @@ class Order:
 
     id: str
     live_mode: bool
+    available_actions: Sequence[str]
     base_amount: Optional[str]
     base_currency: Optional[str]
     booking_reference: str
     cancelled_at: Optional[datetime]
+    content: str
     created_at: datetime
     synced_at: Optional[datetime]
     documents: Sequence[OrderDocument]
@@ -519,6 +521,7 @@ class Order:
         """Construct a class instance from a JSON response."""
         return cls(
             id=json["id"],
+            available_actions=json["available_actions"],
             live_mode=json["live_mode"],
             base_amount=json.get("base_amount"),
             base_currency=json.get("base_currency"),
@@ -528,6 +531,7 @@ class Order:
                 "cancelled_at",
                 lambda value: datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%fZ"),
             ),
+            content=json["content"],
             created_at=datetime.strptime(json["created_at"], "%Y-%m-%dT%H:%M:%S.%fZ"),
             synced_at=get_and_transform(
                 json,
