@@ -14,11 +14,11 @@ def fixture(name, url_path, mock, status_code, with_response=True):
     with open(f"tests/fixtures/{name}.json") as fh:
         if with_response:
             response = json.loads(fh.read())
-            uri = "{}/{}".format(url, url_path)
+            uri = f"{url}/{url_path}"
             mock(uri, complete_qs=True, json=response, status_code=status_code)
             yield Duffel(access_token="some_token", api_url=url)
         else:
-            uri = "{}/{}".format(url, url_path)
+            uri = f"{url}/{url_path}"
             mock(uri, complete_qs=True, status_code=status_code)
             yield Duffel(access_token="some_token", api_url=url)
 
